==> ofscraper-3.10.dev8-py3-none-any.whl: ofscraper/utils/live/progress.py <==
from rich.live import Live
from rich.progress import (
    BarColumn,
    DownloadColumn,
    MofNCompleteColumn,
    Progress,
    SpinnerColumn,
    TaskProgressColumn,
    TextColumn,
    TransferSpeedColumn,
)
from rich.style import Style
from rich.table import Column

import ofscraper.utils.console as console_
from ofscraper.classes.multiprocessprogress import MultiprocessProgress as MultiProgress

# activity
activity_progress = Progress(
    TextColumn("[white]{task.description}[/white]"),
)
activity_counter = Progress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(table_column=Column(ratio=3), bar_width=100),
    MofNCompleteColumn(),
)

# download progress
download_job_progress = Progress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(),
    TaskProgressColumn(),
    console=console_.get_shared_console(),
)


multi_download_job_progress = MultiProgress(
    TextColumn("[white]{task.description}[/white]", table_column=Column(ratio=2)),
    BarColumn(),
    TaskProgressColumn(),
    TransferSpeedColumn(),
    DownloadColumn(),
)

download_overall_progress = Progress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(),
    TaskProgressColumn(),
)


# user progress
userlist_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
)
userlist_job_progress = Progress("[white]{task.description}[/white]")


# like progress

like_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(table_column=Column(ratio=2)),
    MofNCompleteColumn(),
)
# api
api_job_progress = Progress(
    "[white]{task.description}[/white]", console=console_.get_shared_console()
)
api_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
    console=console_.get_shared_console(),
)

==> ofscraper-3.10.15-py3-none-any.whl: ofscraper/utils/live/progress.py <==
from rich.progress import (
    BarColumn,
    DownloadColumn,
    MofNCompleteColumn,
    Progress,
    SpinnerColumn,
    TaskProgressColumn,
    TextColumn,
)
from rich.style import Style
from rich.table import Column

import ofscraper.utils.console as console_
from ofscraper.classes.progress.progress import MultiprocessFileProgress as MultiFileProgress,FileProgress,OverallFileProgress
from ofscraper.classes.progress.transfercol import OverallTransferSpeedColumn,TransferFileSpeedColumn
# activity
activity_progress = Progress(
    TextColumn("[white]{task.description}[/white]"),
    refresh_per_second =2
)
activity_counter = Progress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(table_column=Column(ratio=3), bar_width=100),
    MofNCompleteColumn(),
        refresh_per_second =2

)

# download progress
download_job_progress = FileProgress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(),
    TaskProgressColumn(),
    TransferFileSpeedColumn(),
    DownloadColumn(),
    console=console_.get_shared_console(),
            refresh_per_second =1.5,
            auto_refresh=True


)

multi_download_job_progress = MultiFileProgress(
    TextColumn("[white]{task.description}[/white]", table_column=Column(ratio=2)),
    BarColumn(),
    TaskProgressColumn(),
    TransferFileSpeedColumn(),
    DownloadColumn(),
                refresh_per_second =3,
                        auto_refresh=True


)

download_overall_progress = OverallFileProgress(
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(),
    TaskProgressColumn(),
    OverallTransferSpeedColumn(),
        refresh_per_second =3,
        auto_refresh=True

)



# user progress
userlist_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
                refresh_per_second =5

)
userlist_job_progress = Progress("[white]{task.description}[/white]")


# like progress

like_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
    BarColumn(table_column=Column(ratio=2)),
    MofNCompleteColumn(),
                    refresh_per_second =5

)
# api
api_job_progress = Progress(
    "[white]{task.description}[/white]", console=console_.get_shared_console(),
                        refresh_per_second =5

)
api_overall_progress = Progress(
    SpinnerColumn(style=Style(color="blue")),
    TextColumn("[white]{task.description}[/white]"),
    console=console_.get_shared_console(),
                            refresh_per_second =5

)
